@@ -7,7 +7,7 @@ BEGIN
 	use warnings;
 	use vars qw( $VERSION $LocaleRange );
 
-	$VERSION = '0.08';
+	$VERSION = '0.09';
 
 	$LocaleRange = qr/\p{InBasicLatin}/;
 }
@@ -810,7 +810,7 @@ __END__
 
 =head1 NAME
 
-Text::TransMetaphone::en_US – Transcribe American English words into IPA symbols.
+Text::TransMetaphone::en_US - Transcribe American English words into IPA symbols.
 
 =head1 SYNOPSIS
 
